@@ -512,6 +512,7 @@ init_ui (void)
 		buddy_set_text ("gdb-pid-entry", s);
 		druid_data.bug_type = BUG_CRASH;
 		druid_data.crash_type = CRASH_DIALOG;
+		druid_set_state (STATE_GDB);
 	}
 
 	/* core crash page */
@@ -519,6 +520,7 @@ init_ui (void)
 		buddy_set_text ("gdb-core-entry", popt_data.core_file);
 		druid_data.crash_type = CRASH_CORE;
 		druid_data.bug_type = BUG_DEBUG;
+		druid_set_state (STATE_GDB);
 	}
 
 	/* package version */
@@ -587,14 +589,22 @@ init_ui (void)
 			"How often does this happen?\n\n\n"
 			"Additional Information:\n");
 
-	/* set the cursor at the beginning of the second line */
+	/* set the cursor at the beginning of the second line
+	 * in the description page, and crearte the lock tag
+	 * for the email review page */
 	{
-		GtkTextBuffer *buffy;
+		GtkTextBuffer *desc_buffer, *email_buffer;
 		GtkTextIter iter;
+		GtkTextTag *tag;
+
+		desc_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
+		gtk_text_buffer_get_iter_at_line (desc_buffer, &iter, 1);
+		gtk_text_buffer_place_cursor (desc_buffer, &iter);
+		/* Create the tag for locking the headers */
+		email_buffer = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("email-text")));
+		tag = gtk_text_buffer_create_tag (email_buffer, "lock_tag",
+						  "editable", FALSE, NULL);
 
-		buffy = gtk_text_view_get_buffer (GTK_TEXT_VIEW (GET_WIDGET ("desc-text")));
-		gtk_text_buffer_get_iter_at_line (buffy, &iter, 1);
-		gtk_text_buffer_place_cursor (buffy, &iter);
 	}
 }
 
