@@ -941,11 +941,13 @@ load_bugzillas (void)
 #define BUGZILLA_PRODUCT                "X-GNOME-Bugzilla-Product"
 #define BUGZILLA_COMPONENT              "X-GNOME-Bugzilla-Component"
 #define BUGZILLA_EMAIL                  "X-GNOME-Bugzilla-Email"
+#define BUGZILLA_VERSION                "X-GNOME-Bugzilla-Version"
 #define BUGZILLA_OTHER_BINARIES         "X-Gnome-Bugzilla-OtherBinaries"
 
 #define BA_BUGZILLA_BUGZILLA            "bugzilla:bugzilla"
 #define BA_BUGZILLA_PRODUCT             "bugzilla:product"
 #define BA_BUGZILLA_COMPONENT           "bugzilla:component"
+#define BA_BUGZILLA_VERSION             "bugzilla:version"
 #define BA_BUGZILLA_EMAIL               "bugzilla:email"
 #define BA_BUGZILLA_OTHER_BINARIES      "bugzilla:other_binaries"
 
@@ -955,6 +957,7 @@ bugzilla_application_new (const char *name,
 			  const char *bugzilla, 
 			  const char *product,
 			  const char *component, 
+			  const char *version, 
 			  const char *email, 
 			  const char *icon,
 			  const char *program,
@@ -974,6 +977,7 @@ bugzilla_application_new (const char *name,
 	app->bugzilla    = g_strdup (bugzilla);
 	app->product     = g_strdup (product);
 	app->component   = g_strdup (component);
+	app->version     = g_strdup (version);
 	app->email       = g_strdup (email);
 
 	if (icon && *icon != G_DIR_SEPARATOR)
@@ -996,7 +1000,6 @@ bugzilla_application_new (const char *name,
 		g_error_free (error);
 	}
 	
-	druid_data.applications = g_slist_prepend (druid_data.applications, app);
 
 	if (program) {
 		g_shell_parse_argv (program, &i, &programv, NULL);
@@ -1007,11 +1010,21 @@ bugzilla_application_new (const char *name,
 			if (g_hash_table_lookup (druid_data.program_to_application, s) == NULL) {
 				d(g_print ("adding app: %s\n", s));
 				g_hash_table_insert (druid_data.program_to_application, g_strdup (s), app);
+				druid_data.applications = g_slist_prepend (druid_data.applications, app);
+			} else {
+				g_free (app);
+				return;
 			}
+		} else {
+			g_free (app);
+			return;
 		}
 		if (programv)
 			g_strfreev (programv);
+	} else {
+		druid_data.applications = g_slist_prepend (druid_data.applications, app);
 	}
+		
 
 	if (other_programs) {
 		programv = g_strsplit (other_programs, ";", -1);
@@ -1073,6 +1086,7 @@ load_applets (GnomeIconTheme *git)
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_BUGZILLA,  NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_PRODUCT,   NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_COMPONENT, NULL),
+			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_VERSION, NULL),
 			bonobo_server_info_prop_lookup (info, BA_BUGZILLA_EMAIL,     NULL),
 			bonobo_server_info_prop_lookup (info, "panel:icon", NULL),
 			NULL,
@@ -1126,6 +1140,7 @@ visit_cb (const char *rel_path,
 		gnome_desktop_item_get_string (ditem, BUGZILLA_BUGZILLA),
 		gnome_desktop_item_get_string (ditem, BUGZILLA_PRODUCT),
 		gnome_desktop_item_get_string (ditem, BUGZILLA_COMPONENT),
+		gnome_desktop_item_get_string (ditem, BUGZILLA_VERSION),
 		gnome_desktop_item_get_string (ditem, BUGZILLA_EMAIL),
 		icon,
 		gnome_desktop_item_get_string (ditem, GNOME_DESKTOP_ITEM_EXEC),
@@ -1218,7 +1233,9 @@ add_product (gpointer key, BugzillaProduct *p, GtkListStore *store)
 static void
 add_products (gpointer key, BugzillaBTS *bts, GtkListStore *store)
 {
-	g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
+	if (bts->products != NULL) {
+		g_hash_table_foreach (bts->products, (GHFunc)add_product, store);
+	}
 }
 
 static void
@@ -1441,6 +1458,8 @@ generate_email_text (gboolean include_headers)
 		g_string_append_printf (email, "Synopsis: %s\n", subject);
 		g_string_append_printf (email, "Bugzilla-Product: %s\n", druid_data.product->name);
 		g_string_append_printf (email, "Bugzilla-Component: %s\n", druid_data.component->name);
+		g_string_append_printf (email, "Bugzilla-Version: %s\n", version);
+
 		if (druid_data.bug_type == BUG_DOC)
 			g_string_append_printf (email, "Bugzilla-Keyword: doc\n");
 		if (druid_data.bug_type == BUG_I18N)
